@@ -1,4 +1,4 @@
-__version__ = "1.0.0"
+__version__ = "1.1.6"
 
 
 import os
@@ -6,11 +6,11 @@ import os
 os.system(
     f'python {os.path.split(__file__)[0]}/env_info/check_version_and_update.py '
     f'--package_name kevin-toolbox-dev '
-    f'--cur_version {__version__} --verbose True'
+    f'--cur_version {__version__} --verbose 0'
 )
 
 os.system(
     f'python {os.path.split(__file__)[0]}/env_info/check_validity_and_uninstall.py '
     f'--package_name kevin-toolbox-dev '
-    f'--expiration_timestamp 1688042370 --verbose True'
+    f'--expiration_timestamp 1705840454 --verbose 0'
 )
